<?php
/**
 * Initialization routines for the MythWeb TV module.
 *
 * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/tv/init.php $
 * @date        $Date: 2007-12-31 20:38:38 +0000 (Mon, 31 Dec 2007) $
 * @version     $Revision: 15274 $
 * @author      $Author: xris $
 * @license     GPL
 *
 * @package     MythWeb
 * @subpackage  TV
 *
/**/

    $Settings['tv'] = array('name'    => t('TV'),
                            'choices' => array('session'   => t('My Session'),
                                               'channels'  => t('Channel Info'),
                                               'playgroup' => t('Playback Groups'),
                                              ),
                            'default' => 'session',
                           );

// The TV module is always enabled.
    $Modules['tv'] = array('path'        => 'tv',
                           'sort'        => 1,
                           'name'        => t('TV'),
                           'links'       => array('list'             => t('Program Listing'),
                                                  'searches'         => t('Special Searches'),
                                                  'upcoming'         => t('Upcoming Recordings'),
                                                  'schedules'        => t('Recording Schedules'),
                                                  'schedules/manual' => t('Schedule Manually'),
                                                  'schedules/custom' => t('Custom Schedule'),
                                                  'recorded'         => t('Recorded Programs'),
                                                 ),
                          );

